# -*- coding: utf-8 -*-
import sys
import json
import requests

# python client.py file.json [ner] [sym] [tratamento=anotação|remoção|máscara_constante|máscara_proporcional]

URL = "http://127.0.0.1:8602/deid/"
TIMEOUT = None
PAYLOAD = 1 << 20

json_input = sys.argv[1]
ner = "ner" in sys.argv
sym = "sym" in sys.argv
treatment = "anotação"
for t in ["anotação", "remoção", "máscara_constante", "máscara_proporcional"]:
    if t in sys.argv:
        treatment = t
        break

def request(texts, ner, sym, treatment):
    response = requests.post(URL, json={"txt": texts, "ner": ner, "sym": sym, "tratamento": treatment}, timeout=TIMEOUT)
    if response.status_code != 200:
        sys.exit("Request failure, status code: ", response.status_code)
    return response.json()['txt']

with open(json_input) as jsonfile:
    patients = json.load(jsonfile)
    for patient in patients:
        name = patient["Nome"]
        print("Paciente: ", name)
        updates = patient["Atualizações"]
        request_text = [entry["descricao"] for entry in updates]
        request_response = []
        previous_index = index = size = 0
        # Break batches according to payload limits
        while index < len(request_text):
            if size + len(request_text[index]) <= PAYLOAD:
                size += len(request_text[index])
                index += 1
            else:
                request_response.append(request(request_text[previous_index:index], ner, sym, treatment))
                size = 0
                previous = index
        if index != previous_index:
            request_response.append(request(request_text[previous_index:index], ner, sym, treatment))
        # Show changes
        for entry, text, text_mod in zip(updates, request_text, request_response):
            print("Descrição original:")
            print(text)
            print("Descrição modificada:")
            print(text_mod)
            # Update structure
            entry["descricao"] = text_mod
        print("---\n\n")
    # Save modified file
    with open(json_input.removesuffix(".json") + "_modificado.json", 'w') as outputfile:
        json.dump(patients, outputfile, ensure_ascii=False)
